@@ -47,7 +47,7 @@ def EmailFormatValidator(email):
 
 def ContainsOnlyDigits(str_value):
     """
-     Returns the count of the number of times a string value appears in a string
+     Validates if a value contains only digits
        Returns PASS (str_value contains only digits) or FAIL (str_value does not
        contain only digits)
     """
@@ -64,12 +64,14 @@ def ConvertStringToList(string):
     ConvLst = list(string.split(" ")) 
     return ConvLst 
 
-def GetValueInString(Value, str): 
+def GetValueInString(value, str): 
     """
-     Returns the string (str) passed in if it is contained within the Value or Returns FAIL if the string
-       is not contained within the Value.
+     Returns the string value (value) passed in if it is contained within the string (str) or Returns FAIL if the string value (value)
+       is not contained within the string (str).
     """
-    Match = re.findall(Value, str)
+    value = value.lower()
+    str = str.lower()
+    Match = re.findall(value, str)
     if Match: 
        return    Match
     else: 
@@ -93,34 +95,36 @@ def StringFormatValidator(field_format, field_value):
 
 def GetStringPosition(str,fnd): 
     """
-    Returns the index of the positive of a string (fnd) contained in the string value passed in (str)
+    Returns the index of the position of a the first occurrence of a string (fnd) contained in the string value passed in (str)
     """
+    str = str.lower()
+    fnd = fnd.lower()
     pos = 0
     ind = str.find(fnd)
     pos += str.find(fnd)
     return pos
 
-def GetUniqueItems(list_values):
+def GetUniqueItem(list_values):
   """
-  Returns the unique list of values from argument list_values
+  Returns the unique list of values from parameter list_values
   """
   for x in list_values:
       if list_values.count(x) > 1:
          list_values.remove(x)
-  return result
+  return list_values
 
 def CountOccurenceOfValueInString(string,sub_string):
     """
      Returns the count of the number of times a value appears in a string
     """
+    string = string.lower()
+    sub_string = sub_string.lower()
     l=len(sub_string)
     count=0
     for i in range(len(string)-len(sub_string)+1):
         if(string[i:i+len(sub_string)] == sub_string ):      
             count+=1
-    return count  
-    
-   
+    return count     
 
 def DisposeWebDriver():
         """
